@@ -196,101 +196,6 @@ class DropoutTrxDataset(Dataset):
             return new_x
 
 
-class AllTimeShuffleDataset(Dataset):
-    """Shuffle all transactions in event sequence
-    """
-    def __init__(self, dataset, event_time_name='event_time'):
-        self.dataset = dataset
-        self.shuffler = AllTimeShuffle(event_time_name)
-        self.style = dataset.style
-
-    def __len__(self):
-        return len(self.dataset)
-
-    def __getitem__(self, item):
-        x, y = self.dataset[item]
-        new_x = self.shuffler(x)
-        return new_x, y
-
-
-class AllTimeShuffleMLDataset(Dataset):
-    """Shuffle all transactions in event sequence
-    """
-    def __init__(self, dataset, event_time_name='event_time'):
-        self.core_dataset = dataset
-        self.shuffler = AllTimeShuffle(event_time_name)
-        self.style = dataset.style
-
-    def __len__(self):
-        return len(self.core_dataset)
-
-    def __getitem__(self, idx):
-        item = self.core_dataset[idx]
-        if type(item) is list:
-            return [self._one_item(t) for t in item]
-        else:
-            return self._one_item(item)
-
-    def _one_item(self, item):
-        x, y = item
-        new_x = self.shuffler(x)
-        return new_x, y
-
-
-class SameTimeShuffleDataset(Dataset):
-    """Split sequences on intervals with equal event times. Shuffle events in each split independently
-    """
-    def __init__(self, dataset, event_time_name='event_time'):
-        self.dataset = dataset
-        self.event_time_name = event_time_name
-
-    def __len__(self):
-        return len(self.dataset)
-
-    @staticmethod
-    def get_perm_ix(event_time):
-        ix = []
-        pos = 0
-        for time in torch.unique(event_time, sorted=True):
-            mask = event_time == time
-            n = mask.sum()
-            _ix = torch.randperm(n)
-            ix.append(_ix + pos)
-            pos += n
-        return torch.cat(ix, dim=0)
-
-    def __getitem__(self, item):
-        x, y = self.dataset[item]
-        ix = self.get_perm_ix(x[self.event_time_name])
-        new_x = {k: v[ix] for k, v in x.items()}
-        return new_x, y
-
-
-class DropDayDataset(Dataset):
-    """Split sequences on intervals with equal event times. Shuffle events in each split independently
-    """
-    def __init__(self, dataset, event_time_name='event_time'):
-        self.dataset = dataset
-        self.event_time_name = event_time_name
-        self.style = dataset.style
-
-    def __len__(self):
-        return len(self.dataset)
-
-    @staticmethod
-    def get_perm_ix(event_time):
-        days = torch.unique(event_time, sorted=True)
-        ix = np.random.choice(len(days), 1)[0]
-        mask = event_time != days[ix]
-        return mask
-
-    def __getitem__(self, item):
-        x, y = self.dataset[item]
-        mask = self.get_perm_ix(x[self.event_time_name])
-        new_x = {k: v[mask] for k, v in x.items()}
-        return new_x, y
-
-
 class LastKTrxDataset(Dataset):
     def __init__(self, dataset: Dataset, share):
         self.core_dataset = dataset
