@@ -8,3 +8,6 @@ from .triplet_loss import TripletLoss
 
 from .histogram_loss import HistogramLoss
 from .centroid_loss import CentroidLoss, CentroidSoftmaxLoss, CentroidSoftmaxMemoryLoss
+
+from .softmax_loss import SoftmaxLoss
+from .softmax_pairwise_loss import SoftmaxPairwiseLoss
