@@ -2,9 +2,13 @@
 from .all_positive_pair_selector import AllPositivePairSelector
 from .hard_negative_pair_selector import HardNegativePairSelector
 from .distance_weighted_pair_selector import DistanceWeightedPairSelector
+from .pairwise_matrix_selector import PairwiseMatrixSelector
 
 # Triplets
 from .all_triplets_selector import AllTripletSelector
 from .hard_triplet_selector import HardTripletSelector
 from .random_negative_triplet_selector import RandomNegativeTripletSelector
 from .semi_hard_triplet_selector import SemiHardTripletSelector
+
+# Masker
+from .matrix_masker import MatrixMasker
\ No newline at end of file
