@@ -4,7 +4,8 @@ from .trx_encoder import (
 
 from .seq_encoder import (
     RnnEncoder,  TransformerEncoder, LongformerEncoder,
-    RnnSeqEncoder, TransformerSeqEncoder, LongformerSeqEncoder, AggFeatureSeqEncoder
+    RnnSeqEncoder, TransformerSeqEncoder, LongformerSeqEncoder, AggFeatureSeqEncoder,
+    GptEncoder
 )
 
 from .pb import PBDropout, PBLinear, PBL2Norm, PBLayerNorm, PBReLU
