@@ -1,8 +1,10 @@
 from .rnn_encoder import RnnEncoder
 from .transformer_encoder import TransformerEncoder
 from .longformer_encoder import LongformerEncoder
+from .gpt_encoder import GptEncoder
+from .custom_encoder import Encoder
 
-from .containers import RnnSeqEncoder, TransformerSeqEncoder, LongformerSeqEncoder
+from .containers import RnnSeqEncoder, TransformerSeqEncoder, LongformerSeqEncoder, CustomSeqEncoder
 from .agg_feature_seq_encoder import AggFeatureSeqEncoder
 
 # from ptls.nn.seq_encoder.rnn_seq_encoder_distribution_target import RnnSeqEncoderDistributionTarget
